/*
   Name:    "HelloWorld-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in HelloWorld-oo.rex"
                or
            "java com.ibm.bsf.Main            -in HelloWorld-oo.rex"
                or
             "rexxj HelloWorld-oo.rex"
                or
             "rexx HelloWorld-oo.rex"

   Purpose:  create a window with a choice-object and two text-fields and buttons;
             if the ok-button is pressed then popup another window and display what
             was chosen and entered.

             This version stresses Object Rexx and the wrapper class "BSF.cls" which
             makes Java look like if it was Object Rexx ...
             ;)

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-18, 2003-01-23

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."


        /* create a Java awt window and a Java awt button       */
tmpWin = .awtFrame~new("String", 'Hello World!')

.bsf~import("awtButton", "java.awt.Button")     /* another way to define a Java class   */
tmpBut = .awtButton~new("String", 'Drck mich!')

        /* prepare window and show it   */
tmpWin ~~add("Object", tmpBut) ~~pack ~~show ~~toFront

        /* define which eventText has to be sent on which event         */
tmpWin~bsf.addEventListener('window', 'windowClosing', 'call bsf "exit"')
tmpBut~bsf.addEventListener('action', ''             , 'call BSF exit')

        /* run the event loop, otherwise this instance of Rexx gets shut down   */
        /* dispatch the strings received as a result of the registered events   */
do forever
   a = bsf("pollEventText")     /* wait for an eventText to be sent     */
   interpret a                  /* execute as a Rexx program            */
   say "(in Rexx), polled: ["a"]"
   if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown */
end
say "Now exiting Rexx."


::REQUIRES "BSF.cls"    -- requires the BSF-class

        /* one way, how to define a Java class in Object Rexx   */
::CLASS "awtFrame" SUBCLASS bsf
::METHOD init
  self~init:super('java.awt.Frame', ARG(1, 'A'))

